'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var lambdaResp = {
  /**
   * Lwqmbda standard success response.
   *
   * @param  {integer}  statusCode  - Http status code to be mapped.
   * @param  {object}  data  - Payload to return.
   * @return {object}  - Response object to return, success statuses should return through the first
   *                     param in the Lambda callback so this does not need to be stringified.
   */

  success: function success(statusCode, data) {
    var response = {};
    response.status = 'success';
    response.httpStatus = statusCode;
    response.data = data;

    return response;
  },


  /**
   * Lambda standard error response.
   *
   * @param  {integer}  statusCode  - Http status code to be mapped.
   * @param  {string}  message  - Error message.
   * @param  {data}  data  - Additional error information.
   * @return  {string}  - Stringified standard object. Has to be stringified, as Lambda tries to
   *                      return the first param in the callback function as a string.
   */
  error: function error(statusCode, message, data) {
    var response = {};
    response.status = 'error';
    response.httpStatus = statusCode;
    response.message = message;
    response.data = data;

    return (0, _stringify2.default)(response);
  },


  /**
   * Lambda standard error response.
   *
   * @param  {integer}  statusCode  - Http status code to be mapped.
   * @param  {object}  data  - Payload to return.
   * @return  {string}  - Stringified standard object. Has to be stringified, as Lambda tries to
   *                      return the first param in the callback function as a string.
   */
  fail: function fail(statusCode, data) {
    var response = {};
    response.status = 'fail';
    response.data = data;
    response.httpStatus = statusCode;

    return (0, _stringify2.default)(response);
  }
};

exports.default = lambdaResp;