'use strict';

var _chai = require('chai');

var _chai2 = _interopRequireDefault(_chai);

var _index = require('../index');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var expect = _chai2.default.expect; /* eslint-env node, mocha */


describe('AWS Lambda Standard Response', function () {
  it('Builds a success structure and returns it as an object', function () {
    var result = _index2.default.success(200, { hello: 'world' });

    expect(result).to.be.an('object');
    expect(result.status).to.equal('success');
    expect(result.httpStatus).to.equal(200);
    expect(result.data).to.be.an('object');
    expect(result.data.hello).to.equal('world');
  });

  it('Builds a JSON stringified error structure with a data object.', function () {
    var result = _index2.default.error(503, 'A service this called was unavailable');
    var resultObject = JSON.parse(result);

    expect(result).to.be.a('string');
    expect(resultObject).to.be.an('object');
    expect(resultObject.status).to.equal('error');
    expect(resultObject.httpStatus).to.equal(503);
    expect(resultObject.data).to.equal(undefined);
    expect(resultObject.message).to.equal('A service this called was unavailable');
  });

  it('Builds a JSON stringified error structure without a data object.', function () {
    var result = _index2.default.error(500, 'Something went terribly wrong.', { hello: 'world' });
    var resultObject = JSON.parse(result);

    expect(result).to.be.a('string');
    expect(resultObject).to.be.an('object');
    expect(resultObject.status).to.equal('error');
    expect(resultObject.httpStatus).to.equal(500);
    expect(resultObject.data).to.be.an('object');
    expect(resultObject.data.hello).to.equal('world');
    expect(resultObject.message).to.equal('Something went terribly wrong.');
  });

  it('Builds a JSON stringified fail structure.', function () {
    var result = _index2.default.fail(400, { message: 'Address 1 parameter not specified.' });
    var resultObject = JSON.parse(result);

    expect(result).to.be.a('string');
    expect(resultObject).to.be.an('object');
    expect(resultObject.status).to.equal('fail');
    expect(resultObject.httpStatus).to.equal(400);
    expect(resultObject.data).to.be.an('object');
    expect(resultObject.data.message).to.equal('Address 1 parameter not specified.');
  });
});